#
# Conditional build:
%bcond_without	apidocs	# API documentation
%bcond_without	stemmer	# stemmer support
#
Summary:	Library to create or query compressed XML files
Summary(pl.UTF-8):	Biblioteka do tworzenia i odpytywania skompresowanych plików XML
Name:		libxmlb
Version:	0.3.2
Release:	1
License:	LGPL v2.1+
Group:		Libraries
Source0:	https://people.freedesktop.org/~hughsient/releases/%{name}-%{version}.tar.xz
# Source0-md5:	95f939cb1e165a5ee2e61105e8ef7285
URL:		https://github.com/hughsie/libxmlb
BuildRequires:	glib2-devel >= 1:2.45.8
BuildRequires:	gobject-introspection-devel
%{?with_apidocs:BuildRequires:	gtk-doc}
%{?with_stemmer:BuildRequires:	libstemmer-devel}
BuildRequires:	libuuid-devel
BuildRequires:	meson >= 0.47.0
BuildRequires:	ninja >= 1.5
BuildRequires:	python3 >= 1:3
BuildRequires:	rpm-build >= 4.6
BuildRequires:	rpmbuild(macros) >= 1.736
BuildRequires:	tar >= 1:1.22
BuildRequires:	xz
Requires:	glib2 >= 1:2.45.8
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
XML is slow to parse and strings inside the document cannot be memory
mapped as they do not have a trailing NUL char. The libxmlb library
takes XML source, and converts it to a structured binary
representation with a deduplicated string table - where the strings
have the NULs included.

This allows an application to mmap the binary XML file, do an XPath
query and return some strings without actually parsing the entire
document. This is all done using (almost) zero allocations and no
actual copying of the binary data.

%description -l pl.UTF-8
XML jest wolny do analizy, a łańcuchy znaków wewnątrz dokumentu nie
mogą być odwzorowane w pamięci, ponieważ nie mają końcowych znaków
NUL. Biblioteka libxmlb pobiera źródło XML i przekształca je do
strukturalnej reprezentacji binarnej z zdeduplikowaną tablicą
łańcuchów znaków - w której łańcuchy mają końcowy znak NUL.

Pozwala to aplikacjom odwzorować w pamięci binarny plik XML, wykonać
zapytanie XPath i zwrócić jakieś łańcuchy znaków bez analizy całego
dokumentu. Jest to wykonywane (prawie) bez przydzielania pamięci ani
kopiowania danych binarnych.

%package devel
Summary:	Header files for libxmlb library
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki libxmlb
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	glib2-devel >= 1:2.45.8
Requires:	libstemmer-devel

%description devel
Header files for libxmlb library.

%description devel -l pl.UTF-8
Pliki nagłówkowe biblioteki libxmlb.

%package static
Summary:	Static libxmlb library
Summary(pl.UTF-8):	Statyczna biblioteka libxmlb
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static libxmlb library.

%description static -l pl.UTF-8
Statyczna biblioteka libxmlb.

%package apidocs
Summary:	API documentation for libxmlb library
Summary(pl.UTF-8):	Dokumentacja API biblioteki libxmlb
Group:		Documentation
BuildArch:	noarch

%description apidocs
API documentation for libxmlb library.

%description apidocs -l pl.UTF-8
Dokumentacja API biblioteki libxmlb.

%prep
%setup -q

%build
%if %{with stemmer}
CPPFLAGS="%{rpmcppflags} -I/usr/include/libstemmer"
%endif
%meson build \
	%{!?with_apidocs:-Dgtkdoc=false} \
	%{?with_stemmer:-Dstemmer=true} \
	-Dtests=false

%ninja_build -C build

%install
rm -rf $RPM_BUILD_ROOT

%ninja_install -C build

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc MAINTAINERS NEWS README.md
%attr(755,root,root) %{_libdir}/libxmlb.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libxmlb.so.2
%{_libdir}/girepository-1.0/Xmlb-2.0.typelib
%attr(755,root,root) %{_libexecdir}/xb-tool

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libxmlb.so
%{_includedir}/libxmlb-2
%{_datadir}/gir-1.0/Xmlb-2.0.gir
%{_pkgconfigdir}/xmlb.pc

%files static
%defattr(644,root,root,755)
%{_libdir}/libxmlb.a

%if %{with apidocs}
%files apidocs
%defattr(644,root,root,755)
%{_gtkdocdir}/libxmlb
%endif
%changelog
* Thu Jun 10 2021 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/libxmlb.git;a=log;h=master

* Thu Jun 10 2021 Jakub Bogusz <qboosh@pld-linux.org> 87b4d49
- updated to 0.3.2

* Tue Mar 16 2021 Jakub Bogusz <qboosh@pld-linux.org> a10d34a
- updated to 0.3.0

* Sun Feb 28 2021 Jan Rękorajski <baggins@pld-linux.org> 648bc6f
- unconditional noarch subpackages

* Sat Sep 12 2020 Jakub Bogusz <qboosh@pld-linux.org> c001589
- updated to 0.2.1 (note: new soname)

* Sat Apr 18 2020 Jakub Bogusz <qboosh@pld-linux.org> ef4840f
- updated to 0.1.15

* Sat Feb 01 2020 Arkadiusz Miśkiewicz <arekm@maven.pl> f6db33c
- up to 0.1.14

* Thu Sep 12 2019 Jakub Bogusz <qboosh@pld-linux.org> f03f313
- updated to 0.1.11

* Fri Mar 08 2019 Arkadiusz Miśkiewicz <arekm@maven.pl> 9e80e71
- up to 0.1.7

* Sun Nov 18 2018 Jakub Bogusz <qboosh@pld-linux.org> 3baa8a5
- updated to 0.1.4

* Wed Oct 17 2018 Jakub Bogusz <qboosh@pld-linux.org> aecafbb
- new

